tdp_dummy 
=====================
[![Phovea][phovea-image-client]][phovea-url] [![Phovea][phovea-image-server]][phovea-url] [![NPM version][npm-image]][npm-url] [![CircleCI][circleci-image]][circleci-url]

This repository provides a SQLite database with dummy data and additional views for this specific dataset for TargID.

Installation
------------

```
git clone https://github.com/caleydo/tdp_dummy.git
cd tdp_dummy
npm install
```

Testing
-------

```
npm test
```

Building
--------

```
npm run build
```



***

<a href="https://caleydo.org"><img src="http://caleydo.org/assets/images/logos/caleydo.svg" align="left" width="200px" hspace="10" vspace="6"></a>
This repository is part of **[Phovea](http://phovea.caleydo.org/)**, a platform for developing web-based visualization applications. For tutorials, API docs, and more information about the build and deployment process, see the [documentation page](http://phovea.caleydo.org).


[phovea-image-client]: https://img.shields.io/badge/Phovea-Client%20Plugin-F47D20.svg
[phovea-image-server]: https://img.shields.io/badge/Phovea-Server%20Plugin-10ACDF.svg
[phovea-url]: https://phovea.caleydo.org
[npm-image]: https://badge.fury.io/js/tdp_dummy.svg
[npm-url]: https://npmjs.org/package/tdp_dummy
[circleci-image]: https://circleci.com/gh/Caleydo/tdp_dummy.svg?style=shield
[circleci-url]: https://circleci.com/gh/Caleydo/tdp_dummy
